#
# spec file for package python-gwpy
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-gwpy
Version:        3.0.9
Release:        1.1
Summary:        A python package for gravitational-wave astrophysics
License:        GPL-3.0-only
URL:            https://gwpy.github.io/
Source:         https://files.pythonhosted.org/packages/source/g/gwpy/gwpy-%{version}.tar.gz
# PATCH-FIX-UPSTREAM https://gitlab.com/gwpy/gwpy/-/merge_requests/1782
Patch0:         gwpy-numpy-2.0-types.patch
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-astropy >= 4.3.0
Requires:       python-dateparser
Requires:       python-dqsegdb2
Requires:       python-gwdatafind >= 1.1.0
Requires:       python-gwosc >= 0.5.3
Requires:       python-h5py >= 3
Requires:       python-ligo-segments >= 1.0.0
Requires:       python-ligotimegps >= 1.2.1
Requires:       python-matplotlib >= 3.3.0
Requires:       python-numpy >= 1.17
Requires:       python-python-dateutil
Requires:       python-requests
Requires:       python-scipy >= 1.2.0
Requires:       python-tqdm >= 4.10.0
Recommends:     python-PyCBC
Recommends:     python-PyMySQL
Recommends:     python-lalsimulation
Recommends:     python-lscsoft-glue
Suggests:       python-inspiral-range
BuildArch:      noarch
# SECTION test requirements
# BuildRequires:  %%{python_module PyCBC} -- optional, not available on aarch64
BuildRequires:  %{python_module PyMySQL}
BuildRequires:  %{python_module astropy >= 4.3.0}
BuildRequires:  %{python_module dateparser}
BuildRequires:  %{python_module dqsegdb2}
BuildRequires:  %{python_module gwdatafind >= 1.1.0}
BuildRequires:  %{python_module gwosc >= 0.5.3}
BuildRequires:  %{python_module h5py >= 3}
BuildRequires:  %{python_module ligo-segments >= 1.0.0}
BuildRequires:  %{python_module ligotimegps >= 1.2.1}
BuildRequires:  %{python_module lscsoft-glue}
BuildRequires:  %{python_module matplotlib >= 3.3.0}
BuildRequires:  %{python_module numpy >= 1.17}
BuildRequires:  %{python_module pytest-freezegun}
BuildRequires:  %{python_module pytest-socket}
BuildRequires:  %{python_module pytest-xdist}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-dateutil}
BuildRequires:  %{python_module requests-mock}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module scipy >= 1.2.0}
BuildRequires:  %{python_module tqdm >= 4.10.0}
# extra not defined upstream but needed for tests
BuildRequires:  %{python_module ligo-lw}
# /SECTION
# Unsupported archs by upstream
ExcludeArch:    %{ix86}
Requires(post): update-alternatives
Requires(postun): update-alternatives
%python_subpackages

%description
GWpy is a collaboration-driven Python package providing tools for
studying data from ground-based gravitational-wave detectors.

GWpy provides a user-friendly, intuitive interface to the common
time-domain and frequency-domain data produced by the LIGO and Virgo
observatories and their analyses, with easy-to-follow tutorials at each
step.

%prep
%autosetup -p1 -n gwpy-%{version}
sed -Ei "1{/^#!\/usr\/bin\/env python/d}" gwpy/cli/*.py
sed -Ei "1{/^#!\/usr\/bin\/env python/d}" gwpy/utils/sphinx/*.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/gwpy-plot
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%{python_expand sed -i "s/python --blah/$python --blah/" gwpy/utils/tests/test_shell.py
sed -i "s/'python'/'$python'/g" gwpy/utils/tests/test_shell.py
}

# Set TMPDIR to a dir in working dir so that tests can write to it
mkdir ./tmp
export TMPDIR=./tmp

# List of tests to disable
# - automatic skips by python-gwpy-connectionerror-test.patch
# - test_fetch_open_data in multiple modules try to connect to
#   gw-openscience.org
# - test_{range,time}.py: required pkgs unavailable for oS
# - all other disabled tests require network conn via nds2
export DISABLE_TESTS="fetch_open_data or nds2 or test_channel \
or test_coherence or test_get_data or test_gravityspy \
or test_gwf or test_gwpy_plot_timeseries or test_io_losc \
or test_qtransform or test_range or test_run or test_spectrogram \
or test_spectrum or test_table or test_time \
or test_to_from_pycbc"

# examples are not installed into buildroot: test via pyargs
%pytest --pyargs gwpy -k "not ($DISABLE_TESTS)"

%post
%python_install_alternative gwpy-plot

%postun
%python_uninstall_alternative gwpy-plot

%files %{python_files}
%license LICENSE
%doc README.md examples
%python_alternative %{_bindir}/gwpy-plot
%{python_sitelib}/gwpy/
%{python_sitelib}/gwpy-%{version}*-info/

%changelog
* Sun Sep 15 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.0.9:
  * [gh#gwpy/gwpy#1616] Support parsing multiple FFL files for a
    single dataset
  * [gh#gwpy/gwpy#1637] Remove redundant usetex test function
  * [gh#gwpy/gwpy#1641] Add tests for gwpy.timeseries.io.cache
  * [gh#gwpy/gwpy#1747] Fix argument reuse bug in gwpy.cli
  * [gh#gwpy/gwpy#1749] Add Virgo 'HoftOnline' as a preferred
    frametype
  * [gh#gwpy/gwpy#1753] Fix usage of Hann window for Scipy 1.13.0
  * [gh#gwpy/gwpy#1755] Fix test failure with Zenodo rate limit
  * [gh#gwpy/gwpy#1760] Fix array copy compatibility with numpy 2
  * [gh#gwpy/gwpy#1762] Fix usage of Scipy firwin
  * [gh#gwpy/gwpy#1763] Fix usage of Scipy trapezoid in gwpy.astro
  * [gh#gwpy/gwpy#1764] Improve error handling when reading GWF
    with LALFrame
  * [gh#gwpy/gwpy#1765] Add extra unit alias for 's'
- Add gwpy-numpy-2.0-types.patch for compatibility with numpy 2.0
  float types <https://gitlab.com/gwpy/gwpy/-/merge_requests/1782>
* Mon Jan 15 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.0.8:
  * [gh#gwpy/gwpy#1665] Sieve URLs from gwosc client before fetch
  * [gh#gwpy/gwpy#1669] Handle reading LIGO_LW XML files that are
    missing the _ns timing columns.
  * [gh#gwpy/gwpy#1672] Fix bug in TimeSeriesDict.find
  * [gh#gwpy/gwpy#1685] Fix array indexing of Series.xindex
  * [gh#gwpy/gwpy#1688] Silence LAL LIGOTimeGPS warnings when
    parsing a cache
  * [gh#gwpy/gwpy#1691] Use class fixtures to download GWOSC data
    that is used many times
  * [gh#gwpy/gwpy#1694] Fix missing sample when reading with
    non-exact sample times using LALFrame
  * [gh#gwpy/gwpy#1695] Replace maya with dateparser in gwpy.time
  * [gh#gwpy/gwpy#1698] Fix coherene test fixture
  * [gh#gwpy/gwpy#1699] Fix the Zenodo RST utility module
  * [gh#gwpy/gwpy#1712] Drop HAS_TEX for faster startup time
  * [gh#gwpy/gwpy#1713] Track LALSuite rebrand in docs
  * [gh#gwpy/gwpy#1714] Add support for Python 3.12
  * [gh#gwpy/gwpy#1715] Avoid python-framel 8.46.0
  * [gh#gwpy/gwpy#1716] Migrate test requirement to pytest-freezer
  * [gh#gwpy/gwpy#1718] Remove all use of distutils
  * [gh#gwpy/gwpy#1719] Replace datetime.utcnow() with
    datetime.now(UTC)
  * [gh#gwpy/gwpy#1721] Add aliases for LIGO and Virgo's 'time'
    units
  * [gh#gwpy/gwpy#1722] Read the unitX from a GWF with frameCPP
  * [gh#gwpy/gwpy#1723] Allow localhost sockets during dist
    testing
  * [gh#gwpy/gwpy#1728] Fix bugs in inverse FFT normalisation
  * [gh#gwpy/gwpy#1730] Propagate source keyword in
    DataQualityDict.populate
  * [gh#gwpy/gwpy#1733] Update documentation references for
    lscsoft-glue and LALSuite
  * [gh#gwpy/gwpy#1734] Replace sphinx-panels tabs with
    sphinx-immaterial tabs
- New (Build)Requires: python-dateparser.
* Tue Oct 10 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.0.7:
  * No code changes.
- Changes from version 3.0.6:
  * [gh#gwpy/gwpy#1636] Drop support for Python 3.7.
  * [gh#gwpy/gwpy#1649] Don't round TimeSeries.dt when setting via
    sample_rate.
  * [gh#gwpy/gwpy#1654] Fix type comparison lint.
  * [gh#gwpy/gwpy#1661] Fix compatibility with matplotlib 3.8.0.
  * [gh#gwpy/gwpy#1676] Improve tests of TimeSeriesDict.find error
    handling.
  * [gh#gwpy/gwpy#1677] Fix all executable lint issues.
* Wed Jun 21 2023 Ben Greiner <code@bnavigator.de>
- Update to 3.0.5
  * [#1613] Update all GWOSC URLs to gwosc.org
  * [#1608] Fix issues writing StateVector.bits to HDF5
  * [#1610] Fix plotting TimeSeriesDict on separate Axes
  * [#1611] Resample time series for coherence calculation when
    sampling rates differ
  * [#1622] Update LatexInlineDimensional unit formatter for
    Astropy 5.3
  * [#1621] Fix issues with Series.crop precision
  * [#1617] Document the copy keyword for TimeSeriesBaseDict.crop
  * [#1619] Address inconsistency in transfer_function between CSD
    and PSD averaging methods
  * [#1628] Add H0 and L0 to dynamic_scaled exclusion list
- Update requirements
* Tue May 23 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.0.4:
  * [gh#gwpy/gwpy#1606] Fix incompatibility with gwosc 0.7.0.
- Many changes, including backward incompatible ones from versions
  3.0.0 through 3.0.3, see https://github.com/gwpy/gwpy/releases.
- Disable numerous more tests that either require network or have
  missing dependencies.
- Switch to wheel based builds.
- New Requires: python-ligo-lw (also BuildRequires for tests).
* Thu Sep  1 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.1.5:
  * [gh#gwpy/gwpy#1521] fix compatibility with scipy 1.9.0.
  * [gh#gwpy/gwpy#1523] deprecate the gwpy.utils.null_context
    function.
  * [gh#gwpy/gwpy#1530] fix some lint.
* Thu Jan 20 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.1.3:
  * [gh#gwpy/gwpy#1401] update test suite to use tmp_path fixture
    in pytest.
  * [gh#gwpy/gwpy#1418] add support for Python 3.10.
  * [gh#gwpy/gwpy#1439] fix DeprecationWarning emitted in Python
    3.10.
  * [gh#gwpy/gwpy#1438] update timeseries/public example.
  * [gh#gwpy/gwpy#1456] decorate test to skip gracefully on
    network error.
  * [gh#gwpy/gwpy#1457] fix compatibility with python-ligo-lw
    1.8.0.
  * [gh#gwpy/gwpy#1458] fix compatibility with scipy 1.8.0.
- Drop skip_python36 macro: python3.6 is now out of Factory
  anyway.
- Drop python-gwpy-connectionerror-test.patch: No longer required.
- Drop python-gwpy-python3-shell-test.patch: Use sed to substitute
  flavour specific python executable for 'python'.
- Use update-alternatives to install binary; Add Requires(post):
  update-alternatives.
- New BuildRequires: python-setuptools_scm, python-wheel, and (for
  tests) python-lalsimulation.
* Sat Feb 27 2021 Atri Bhattacharya <badshah400@gmail.com>
- Disable python 3.6 builds: no numpy.
* Sun Jan 10 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.0.2:
  * [gh#gwpy/gwpy#1269]: Fix an issue with file path handling.
  * [gh#gwpy/gwpy#1270]: Fix issues with LIGO_LW column handling.
  * [gh#gwpy/gwpy#1278]: Fix compatibility with matplotlib-3.3.3.
  * [gh#gwpy/gwpy#1279]: Fix compatibility with h5py-3.1.0.
  * [gh#gwpy/gwpy#1281]: Fix issue with error reporting when
    reading LIGO_LW arrays.
- Drop python-gwpy-mp-test.patch: incorporated upstream.
* Mon Nov  2 2020 Atri Bhattacharya <badshah400@gmail.com>
- Add python-gwpy-mp-test.patch: fix an assertion error when
  running test_mp.py [gh#gwpy/gwpy#1273].
* Fri Oct  9 2020 Benjamin Greiner <code@bnavigator.de>
- Fix unit test failures
  * update test section BuildRequires
  * python-gwpy-connectionerror-test.patch
- add examples to %%doc
- update Recommends
* Sun Aug 16 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update list of Requires and BuildRequires changed since version
  2.0.
- Drop Group tag.
* Fri Aug  7 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.0.1:
  * [gh#gwpy/gwpy#1259] fix compatibility with matplotlib-3.3.0.
* Mon Aug  3 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.0.0
  * python requirement increased to >=3.6.
  * numpy requirement increased to >=1.12.0.
  * scipy requirement increased to >=1.2.0.
  * astropy requirement increased to >=3.0.0.
  * matplotlib requirement increased to >=3.1.0.
  * [gh#gwpy/gwpy#1247] new GWF I/O API using FrameL.
  * [gh#gwpy/gwpy#1238] new TimeSeries.mask method.
  * [gh#gwpy/gwpy#1139] update to log formatting on plots.
  * [gh#gwpy/gwpy#1207] fix bug writing series to GWF.
  * [gh#gwpy/gwpy#1218] fix API for CIS using requests-ecp.
- Implement %%check section running tests using pytest; add
  necessary BuildRequires for tests to work.
- Add python-gwpy-python3-shell-test.patch: Use python3 when
  testing the python shell.
- Update BuildRequires versions in keeping with upstream
  requirements.
- Drop python2 packages: No longer supported by upstream.
- No longer support i586 (upstream).
* Thu Apr 23 2020 Atri Bhattacharya <badshah400@gmail.com>
- Replace python-bs4 by python-beautifulsoup4 in dependencies.
* Mon Feb  3 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.0.1:
  * No changelog.
* Wed Oct  9 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 0.15.0
* Thu Jan 31 2019 badshah400@gmail.com
- Enable python2 bindings since we have python2-astropy now.
- Only package gwpy-plot for python3.
* Sun Jan 27 2019 badshah400@gmail.com
- Update to version 0.12.2
- Build only against python3 (python2-astropy not available for
  openSUSE >= 1550).
* Fri Jun 15 2018 badshah400@gmail.com
- Initial package.
